A list containing the PubMed search results, STRING results, and summary results.
Arguments
genes_list
A list of gene IDs.
terms_list
A list of search terms.
rank_method
The method to rank pubmed results, either "weighted" or "total". Weighted ranks results based on order of terms inputted. Total ranks results on total sum of publications across all search term combinations. Defaults to "weighted".
species
The NCBI taxon ID of the species. Defaults to 9606 (Homo sapiens).
network_type
The type of string network to use, either "full" or "physical". Defaults to "full".
score_threshold
The minimum score threshold for string interactions. Defaults to 400.
threshold_percentage
Percentage threshold for ranking (default is 20%).
export
Logical indicating whether to export the results. Defaults to FALSE.
file_directory
Directory for saving the output files. Defaults to NULL.
export_format
Format for export, either "csv", "tsv", or "excel".